@@ -1,7 +1,7 @@
 package App::GenModEmbedder;
 
 our $DATE = '2016-12-26'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,6 +48,10 @@ _
                 Complete::Module::complete_module(word=>$args{word});
             },
         },
+        as => {
+            summary => 'Rename the module',
+            schema => 'perl::modname',
+        },
         strip_pod => {
             schema => ['bool*', is=>1],
             default => 1,
@@ -75,6 +79,9 @@ sub gen_mod_embedder {
     my $mod = $args{module};
     (my $mod_pm = "$mod.pm") =~ s!::!/!g;
 
+    my $as = $args{as} // $mod;
+    (my $as_pm = "$as.pm") =~ s!::!/!g;
+
     my $path = Module::Path::More::module_path(module => $mod)
         or return [400, "Can't find module $mod on filesystem"];
 
@@ -85,27 +92,30 @@ sub gen_mod_embedder {
 
     if ($args{strip_pod}) {
         require Perl::Stripper;
-        my $stripper = Perl::Stripper->new();
+        my $stripper = Perl::Stripper->new(
+            # strip_pod => 1, # the default
+        );
         $source = $stripper->strip($source);
     }
 
+    # XXX this is not perfect/proper
+    if ($mod ne $as) {
+        $source =~ s/\b(package\s+)\Q$mod\E\b/$1 . $as/es;
+    }
+
     $source =~ s/\s+\z//s;
     $source .= "\n";
     $source =~ s/^/#/mg;
 
-    # since literal \' and \\ inside single quote gets converted to literal '
-    # and \, we need to escape the prefix \ to \\ in those cases.
-    $source =~ s/\\(?='|\\)/\\\\$1/g;
-
     my $i0 = "    " x $args{indent_level};
 
     my $preamble = "${i0}# BEGIN EMBEDDING MODULE: mod=$mod ver=$version generator=\"".__PACKAGE__." ".(${__PACKAGE__."::VERSION"})."\" generated-at=\"".(scalar localtime)."\"\n";
-    $preamble .= "${i0}unless (eval { require $mod; 1 }) {\n";
+    $preamble .= "${i0}unless (eval { require $as; 1 }) {\n";
     $preamble .= "${i0}    my \$source = '##line ' . (__LINE__+1) . ' \"' . __FILE__ . qq(\"\\n) . <<'EOS';\n";
     my $postamble = "EOS\n";
     $postamble .= "${i0}    \$source =~ s/^#//gm;\n";
     $postamble .= "${i0}    eval \$source; die if \$@;\n";
-    $postamble .= "${i0}    \$INC{'$mod_pm'} = '(set by embedding code in '.__FILE__.')';\n";
+    $postamble .= "${i0}    \$INC{'$as_pm'} = '(set by embedding code in '.__FILE__.')';\n";
     $postamble .= "${i0}}\n";
     $postamble .= "${i0}# END EMBEDDING MODULE\n";
 
@@ -128,7 +138,7 @@ App::GenModEmbedder - Generate a piece of Perl code that embeds a module
 
 =head1 VERSION
 
-This document describes version 0.002 of App::GenModEmbedder (from Perl distribution App-GenModEmbedder), released on 2016-12-26.
+This document describes version 0.003 of App::GenModEmbedder (from Perl distribution App-GenModEmbedder), released on 2016-12-26.
 
 =head1 FUNCTIONS
 
@@ -165,6 +175,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<as> => I<perl::modname>
+
+Rename the module.
+
 =item * B<indent_level> => I<int> (default: 0)
 
 =item * B<module>* => I<perl::modname>
